// src/crm-inbox-v2-message-messages.public.ts
import { renameKeysFromRESTResponseToSDKResponse as renameKeysFromRESTResponseToSDKResponse2 } from "@wix/sdk-runtime/rename-all-nested-keys";
import { transformRESTTimestampToSDKTimestamp as transformRESTTimestampToSDKTimestamp2 } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
import { EventDefinition } from "@wix/sdk-types";

// src/crm-inbox-v2-message-messages.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/crm-inbox-v2-message-messages.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressInboxV2MessagesServiceUrl(opts) {
  const domainToMappings = {
    "www.wixapis.com": [
      {
        srcPath: "/inbox/v2/messages",
        destPath: "/v2/messages"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/inbox-platform-messages",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_inbox_messages";
function listMessages(payload) {
  function __listMessages({ host }) {
    const metadata = {
      entityFqdn: "wix.crm.inbox.v2.message",
      method: "GET",
      methodFqn: "com.wixpress.inbox.v2.MessagesService.ListMessages",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInboxV2MessagesServiceUrl({
        protoPath: "/v2/messages",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload, true),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "messages.createdDate" }]
        }
      ])
    };
    return metadata;
  }
  return __listMessages;
}
function sendMessage(payload) {
  function __sendMessage({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "message.createdDate" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.crm.inbox.v2.message",
      method: "POST",
      methodFqn: "com.wixpress.inbox.v2.MessagesService.SendMessage",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInboxV2MessagesServiceUrl({
        protoPath: "/v2/messages",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "message.createdDate" }]
        }
      ])
    };
    return metadata;
  }
  return __sendMessage;
}

// src/crm-inbox-v2-message-messages.universal.ts
var Orientation = /* @__PURE__ */ ((Orientation2) => {
  Orientation2["UNKNOWN_ORIENTATION"] = "UNKNOWN_ORIENTATION";
  Orientation2["PORTRAIT"] = "PORTRAIT";
  Orientation2["LANDSCAPE"] = "LANDSCAPE";
  return Orientation2;
})(Orientation || {});
var ContentType = /* @__PURE__ */ ((ContentType2) => {
  ContentType2["UNKNOWN_CONTENT"] = "UNKNOWN_CONTENT";
  ContentType2["BASIC"] = "BASIC";
  ContentType2["TEMPLATE"] = "TEMPLATE";
  ContentType2["MINIMAL"] = "MINIMAL";
  ContentType2["FORM"] = "FORM";
  ContentType2["SYSTEM"] = "SYSTEM";
  ContentType2["UNSUPPORTED"] = "UNSUPPORTED";
  return ContentType2;
})(ContentType || {});
var BadgeVisibility = /* @__PURE__ */ ((BadgeVisibility2) => {
  BadgeVisibility2["UNKNOWN_BADGE_VISIBILITY"] = "UNKNOWN_BADGE_VISIBILITY";
  BadgeVisibility2["BUSINESS_AND_PARTICIPANT"] = "BUSINESS_AND_PARTICIPANT";
  BadgeVisibility2["BUSINESS"] = "BUSINESS";
  return BadgeVisibility2;
})(BadgeVisibility || {});
var ChannelType = /* @__PURE__ */ ((ChannelType2) => {
  ChannelType2["UNKNOWN_CHANNEL_TYPE"] = "UNKNOWN_CHANNEL_TYPE";
  ChannelType2["CHAT"] = "CHAT";
  ChannelType2["EMAIL"] = "EMAIL";
  ChannelType2["SMS"] = "SMS";
  ChannelType2["FACEBOOK"] = "FACEBOOK";
  ChannelType2["INSTAGRAM"] = "INSTAGRAM";
  ChannelType2["WHATSAPP"] = "WHATSAPP";
  return ChannelType2;
})(ChannelType || {});
var MessageVisibility = /* @__PURE__ */ ((MessageVisibility2) => {
  MessageVisibility2["UNKNOWN_VISIBILITY"] = "UNKNOWN_VISIBILITY";
  MessageVisibility2["BUSINESS_AND_PARTICIPANT"] = "BUSINESS_AND_PARTICIPANT";
  MessageVisibility2["BUSINESS"] = "BUSINESS";
  return MessageVisibility2;
})(MessageVisibility || {});
var MessageDirection = /* @__PURE__ */ ((MessageDirection2) => {
  MessageDirection2["UNKNOWN_DIRECTION"] = "UNKNOWN_DIRECTION";
  MessageDirection2["BUSINESS_TO_PARTICIPANT"] = "BUSINESS_TO_PARTICIPANT";
  MessageDirection2["PARTICIPANT_TO_BUSINESS"] = "PARTICIPANT_TO_BUSINESS";
  return MessageDirection2;
})(MessageDirection || {});
var IndicationType = /* @__PURE__ */ ((IndicationType2) => {
  IndicationType2["UNKNOWN_INDICATION_TYPE"] = "UNKNOWN_INDICATION_TYPE";
  IndicationType2["SENT"] = "SENT";
  IndicationType2["SEEN"] = "SEEN";
  IndicationType2["ERROR"] = "ERROR";
  IndicationType2["DELIVERED"] = "DELIVERED";
  return IndicationType2;
})(IndicationType || {});
var PerformedBy = /* @__PURE__ */ ((PerformedBy2) => {
  PerformedBy2["UNKNOWN_PERFORMED_BY"] = "UNKNOWN_PERFORMED_BY";
  PerformedBy2["BUSINESS"] = "BUSINESS";
  PerformedBy2["PARTICIPANT"] = "PARTICIPANT";
  return PerformedBy2;
})(PerformedBy || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
var OverrideSenderOptions = /* @__PURE__ */ ((OverrideSenderOptions2) => {
  OverrideSenderOptions2["CALLER"] = "CALLER";
  OverrideSenderOptions2["PARTICIPANT"] = "PARTICIPANT";
  OverrideSenderOptions2["BUSINESS_USER"] = "BUSINESS_USER";
  return OverrideSenderOptions2;
})(OverrideSenderOptions || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function listMessages2(conversationId, visibility, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    conversationId,
    visibility,
    paging: options?.paging,
    sorting: options?.sorting
  });
  const reqOpts = listMessages(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          conversationId: "$[0]",
          visibility: "$[1]",
          paging: "$[2].paging",
          sorting: "$[2].sorting"
        },
        singleArgumentUnchanged: false
      },
      ["conversationId", "visibility", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function sendMessage2(conversationId, message, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    conversationId,
    message,
    sendNotifications: options?.sendNotifications,
    silent: options?.silent,
    sendAs: options?.sendAs
  });
  const reqOpts = sendMessage(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          conversationId: "$[0]",
          message: "$[1]",
          sendNotifications: "$[2].sendNotifications",
          silent: "$[2].silent",
          sendAs: "$[2].sendAs"
        },
        singleArgumentUnchanged: false
      },
      ["conversationId", "message", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/crm-inbox-v2-message-messages.public.ts
function listMessages3(httpClient) {
  return (conversationId, visibility, options) => listMessages2(
    conversationId,
    visibility,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function sendMessage3(httpClient) {
  return (conversationId, message, options) => sendMessage2(
    conversationId,
    message,
    options,
    // @ts-ignore
    { httpClient }
  );
}
var onMessageButtonInteracted = EventDefinition(
  "wix.crm.inbox.v2.message_button_interacted",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths2(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [{ path: "metadata.eventTime" }]
      }
    ])
  )
)();
var onMessageSentToBusiness = EventDefinition(
  "wix.crm.inbox.v2.message_message_sent_to_business",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths2(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.message.createdDate" },
          { path: "metadata.eventTime" }
        ]
      }
    ])
  )
)();

// src/crm-inbox-v2-message-messages.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
import { createEventModule } from "@wix/sdk-runtime/event-definition-modules";
var listMessages4 = /* @__PURE__ */ createRESTModule(listMessages3);
var sendMessage4 = /* @__PURE__ */ createRESTModule(sendMessage3);
var onMessageButtonInteracted2 = createEventModule(onMessageButtonInteracted);
var onMessageSentToBusiness2 = createEventModule(onMessageSentToBusiness);
export {
  BadgeVisibility,
  ChannelType,
  ContentType,
  IndicationType,
  MessageDirection,
  MessageVisibility,
  Orientation,
  OverrideSenderOptions,
  PerformedBy,
  SortOrder,
  WebhookIdentityType,
  listMessages4 as listMessages,
  onMessageButtonInteracted2 as onMessageButtonInteracted,
  onMessageSentToBusiness2 as onMessageSentToBusiness,
  sendMessage4 as sendMessage
};
//# sourceMappingURL=index.mjs.map